@@ -145,7 +145,14 @@ impl From<&Path> for IgnoreFilesFromOriginArgs {
 ///
 /// This function panics if the `args` are not correctly-formed; this can be checked beforehand
 /// without panicking with [`IgnoreFilesFromOriginArgs::check()`].
-#[allow(clippy::future_not_send)]
+#[expect(
+	clippy::future_not_send,
+	reason = "gix_config internals, if this changes: update the doc"
+)]
+#[allow(
+	clippy::too_many_lines,
+	reason = "it's just the discover_file calls that explode the line count"
+)]
 pub async fn from_origin(
 	args: impl Into<IgnoreFilesFromOriginArgs>,
 ) -> (Vec<IgnoreFile>, Vec<Error>) {
@@ -314,7 +321,11 @@ pub async fn from_origin(
 /// ## Async
 ///
 /// This future is not `Send` due to [`gix_config`] internals.
-#[allow(clippy::future_not_send)]
+#[expect(
+	clippy::future_not_send,
+	reason = "gix_config internals, if this changes: update the doc"
+)]
+#[allow(clippy::too_many_lines, reason = "clearer than broken up needlessly")]
 pub async fn from_environment(appname: Option<&str>) -> (Vec<IgnoreFile>, Vec<Error>) {
 	let mut files = Vec::new();
 	let mut errors = Vec::new();
@@ -357,19 +368,15 @@ pub async fn from_environment(appname: Option<&str>) -> (Vec<IgnoreFile>, Vec<Er
 	}
 
 	if !found_git_global {
-		let mut tries = Vec::with_capacity(5);
+		let mut tries = Vec::with_capacity(3);
 		if let Ok(home) = env::var("XDG_CONFIG_HOME") {
 			tries.push(Path::new(&home).join("git/ignore"));
 		}
-		if let Ok(home) = env::var("APPDATA") {
-			tries.push(Path::new(&home).join(".gitignore"));
-		}
-		if let Ok(home) = env::var("USERPROFILE") {
-			tries.push(Path::new(&home).join(".gitignore"));
-		}
 		if let Ok(home) = env::var("HOME") {
 			tries.push(Path::new(&home).join(".config/git/ignore"));
-			tries.push(Path::new(&home).join(".gitignore"));
+		}
+		if let Ok(home) = env::var("USERPROFILE") {
+			tries.push(Path::new(&home).join(".config/git/ignore"));
 		}
 
 		for path in tries {
